===============================
passwordmetrics
===============================

Features
--------

The passwordmetrics module takes a string and gives you a lot of information
about it pertaining it's usefulness as a password.

* Free software: MIT license
* Documentation: http://passwordmetrics.readthedocs.org.

Features
--------

* Gives you a lot of information about a password, such as:
  * Words used in the password
  * Entropy (ie, how hard it is to guess)
* It's configurable for different languages.
* A big english wordlist included.
* L33t compatibility
